==> jc-1.4.0.tar.gz: soot/jbuddy/SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid.h <==
// public class soot.jbuddy.SWIGTYPE_p_f_int_int__void

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 334383d1537ec6be soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid_H_
#define _JC_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$object;

// Typedefs
typedef struct _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$sub_refs	_jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$sub_refs;
typedef struct _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$sub_nonrefs	_jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$sub_nonrefs;
typedef struct _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$refs	_jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$refs;
typedef struct _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$nonrefs	_jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$nonrefs;
typedef struct _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$object	_jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$object;

typedef const struct _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$vmethods	_jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$vmethods;
typedef const struct _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$vtable	_jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$vtable;
typedef const struct _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$vtype	_jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$vtype;

// Constructors
extern void _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$object *);
extern void _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$method$_init$e037f92e255e7cc9(_jc_env *, struct _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$object *, jlong, jboolean);

// Static methods
extern jlong _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$method$getCPtr$f62afff6274c2eee(_jc_env *, struct _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$object *);

// Virtual methods structure
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$vmethods {
};

// Vtable
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$vmethods	soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid;
};

// Vtype
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$vtype {
	_jc_type			type;
	_jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$refs {
    _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$sub_refs	soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$sub_nonrefs {
	jlong	swigCPtr;
};

// Non-reference instance fields (object)
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$sub_nonrefs	soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid;
};

// Object instance structure
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$object {
	_jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$vtype	*vtype;
	_jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$vtype _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$class_object;

#endif	/* _JC_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid_H_ */

==> jc-1.4.6.tar.gz: soot/jbuddy/SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid.h <==
// public class soot.jbuddy.SWIGTYPE_p_f_int_int__void

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 334383d1537ec6be soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid_H_
#define _JC_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$object;

// Typedefs
typedef struct _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$sub_refs	_jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$sub_refs;
typedef struct _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$sub_nonrefs	_jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$sub_nonrefs;
typedef struct _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$refs	_jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$refs;
typedef struct _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$nonrefs	_jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$nonrefs;
typedef struct _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$object	_jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$object;

typedef const struct _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$vmethods	_jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$vmethods;
typedef const struct _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$vtable	_jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$vtable;
typedef const struct _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$vtype	_jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$vtype;

// Constructors
extern void _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$method$_init$e037f92e255e7cc9(_jc_env *, struct _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$object *, jlong, jboolean) _JC_JCNI_ATTR;

// Static methods
extern jlong _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$method$getCPtr$f62afff6274c2eee(_jc_env *, struct _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$vmethods {
};

// Vtable
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$vmethods	soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid;
};

// Vtype
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$vtype {
	_jc_type			type;
	_jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$refs {
    _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$sub_refs	soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$sub_nonrefs {
	jlong	swigCPtr;
};

// Non-reference instance fields (object)
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$sub_nonrefs	soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid;
};

// Object instance structure
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$object {
	_jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$vtype	*vtype;
	_jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$vtype _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid$class_object;

#endif	/* _JC_soot_jbuddy_SWIGTYPE__5fp__5ff__5fint__5fint__5f__5fvoid_H_ */
